@@ -1,3 +1,5 @@
+from typing import Union
+
 import lab as B
 
 from ..matrix import AbstractMatrix
@@ -6,6 +8,6 @@ from ..triangular import LowerTriangular, UpperTriangular
 __all__ = []
 
 
-@B.dispatch({LowerTriangular, UpperTriangular}, AbstractMatrix)
-def cholesky_solve(a, b):
+@B.dispatch
+def cholesky_solve(a: Union[LowerTriangular, UpperTriangular], b: AbstractMatrix):
     return B.solve(B.transpose(a), B.solve(a, b))
