@@ -5,7 +5,7 @@ from ..woodbury import Woodbury
 __all__ = []
 
 
-@B.dispatch(object, object, object)
+@B.dispatch
 def iqf(a, b, c):
     """Compute `transpose(b) inv(a) c` where `a` is assumed to be positive
     definite.
@@ -30,11 +30,11 @@ def iqf(a, b, c):
 B.iqf = iqf
 
 
-@B.dispatch(object, object)
+@B.dispatch
 def iqf(a, b):
     return iqf(a, b, b)
 
 
-@B.dispatch(Woodbury, object, object)
-def iqf(a, b, c):
-    return B.mm(b, B.pd_inv(a), c, tr_a=True)
+@B.dispatch
+def iqf(a: Woodbury, b, c):
+    return B.mm(b, B.pd_inv(a), c, tr_a=True)
\ No newline at end of file
