@@ -6,7 +6,7 @@ from ..lowrank import LowRank
 __all__ = []
 
 
-@B.dispatch(object, object)
+@B.dispatch
 def matmul_diag(a, b, tr_a=False, tr_b=False):
     """Compute the diagonal of the matrix product of `a` and `b`.
 
@@ -27,6 +27,6 @@ def matmul_diag(a, b, tr_a=False, tr_b=False):
 B.matmul_diag = matmul_diag
 
 
-@B.dispatch(LowRank, LowRank)
-def matmul_diag(a, b, tr_a=False, tr_b=False):
-    return B.diag(B.matmul(a, b, tr_a=tr_a, tr_b=tr_b))
+@B.dispatch
+def matmul_diag(a: LowRank, b: LowRank, tr_a=False, tr_b=False):
+    return B.diag(B.matmul(a, b, tr_a=tr_a, tr_b=tr_b))
\ No newline at end of file
