@@ -6,6 +6,6 @@ from ..constant import Constant
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def ones(a):
-    return Constant(B.one(a), *B.shape(a))
+@B.dispatch
+def ones(a: AbstractMatrix):
+    return Constant(B.one(a), *B.shape(a))
\ No newline at end of file
