@@ -5,6 +5,6 @@ from ..matrix import AbstractMatrix
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def zero(a):
-    return B.zero(B.dtype(a))
+@B.dispatch
+def zero(a: AbstractMatrix):
+    return B.zero(B.dtype(a))
\ No newline at end of file
