@@ -4,7 +4,7 @@ from matrix import Dense
 
 # noinspection PyUnresolvedReferences
 from ..util import (
-    allclose,
+    approx,
     check_un_op,
     AssertDenseWarning,
     dense1,
@@ -20,5 +20,5 @@ def test_concat(dense1, dense2, diag1, diag2):
         dense_res = B.concat(
             B.dense(dense1), B.dense(dense2), B.dense(diag1), B.dense(diag2), axis=1
         )
-        allclose(res, dense_res)
+        approx(res, dense_res)
         assert isinstance(res, Dense)
