@@ -2,7 +2,7 @@ import lab as B
 
 # noinspection PyUnresolvedReferences
 from ..util import (
-    allclose,
+    approx,
     check_un_op,
     dense1,
     dense2,
@@ -17,11 +17,11 @@ def _check_iqf(a, b, c):
     res = B.iqf_diag(a, b, c)
 
     # Check correctness.
-    allclose(res, B.diag(B.iqf(a, b, c)))
+    approx(res, B.diag(B.iqf(a, b, c)))
 
 
 def test_iqf_diag_two_arguments(dense_pd, dense1):
-    allclose(B.iqf_diag(dense_pd, dense1), B.iqf_diag(dense_pd, dense1, dense1))
+    approx(B.iqf_diag(dense_pd, dense1), B.iqf_diag(dense_pd, dense1, dense1))
 
 
 def test_iqf_diag_dense(dense_pd, dense1, dense2):
