@@ -12,7 +12,7 @@ from matrix import (
 
 # noinspection PyUnresolvedReferences
 from ..util import (
-    allclose,
+    approx,
     check_un_op,
     AssertDenseWarning,
     zero1,
