@@ -3,11 +3,10 @@ import warnings
 
 import lab as B
 import pytest
-from numpy.testing import assert_allclose, assert_array_almost_equal
-from plum import Dispatcher
+from numpy.testing import assert_allclose
+from plum import Dispatcher, Union
 
 from matrix import (
-    AbstractMatrix,
     Dense,
     Diagonal,
     Zero,
@@ -21,7 +20,6 @@ from matrix import (
 from matrix.util import ToDenseWarning
 
 __all__ = [
-    "allclose",
     "approx",
     "check_un_op",
     "check_bin_op",
@@ -75,23 +73,28 @@ __all__ = [
 
 _dispatch = Dispatcher()
 
-approx = assert_array_almost_equal
 
-
-@_dispatch(object, object)
-def allclose(x, y):
+@_dispatch
+def approx(x, y, rtol=1e-7, atol=1e-12):
     """Assert that two objects are numerically close.
 
     Args:
         x (object): First object.
         y (object): Second object.
+        rtol (float, optional): Relative tolerance. Defaults to `1e-7`.
+        atol (float, optional): Absolute tolerance. Defaults to `1e-12`.
     """
-    allclose(B.to_numpy(x), B.to_numpy(y))
+    approx(B.to_numpy(x), B.to_numpy(y), rtol=rtol, atol=atol)
 
 
-@_dispatch({tuple, B.Number, B.NPNumeric}, {tuple, B.Number, B.NPNumeric})
-def allclose(x, y):
-    assert_allclose(x, y, rtol=1e-7, atol=1e-14)
+@_dispatch
+def approx(
+    x: Union[tuple, B.Number, B.NPNumeric],
+    y: Union[tuple, B.Number, B.NPNumeric],
+    **kw_args,
+):
+    assert_allclose(x, y, **kw_args)
+    assert B.shape(x) == B.shape(y)
 
 
 def _assert_instance(x, asserted_type):
@@ -111,7 +114,7 @@ def check_un_op(op, x, asserted_type=object):
     """
     x_dense = B.dense(x)
     res = op(x)
-    allclose(res, op(x_dense))
+    approx(res, op(x_dense))
     _assert_instance(res, asserted_type)
 
 
@@ -130,13 +133,13 @@ def check_bin_op(op, x, y, asserted_type=object, check_broadcasting=True):
     y_dense = B.dense(y)
     res = op(x, y)
 
-    allclose(res, op(x_dense, y_dense))
+    approx(res, op(x_dense, y_dense))
 
     with IgnoreDenseWarning():
         if check_broadcasting:
-            allclose(op(x_dense, y), op(x_dense, y_dense))
-            allclose(op(x, y_dense), op(x_dense, y_dense))
-        allclose(op(x_dense, y_dense), op(x_dense, y_dense))
+            approx(op(x_dense, y), op(x_dense, y_dense))
+            approx(op(x, y_dense), op(x_dense, y_dense))
+        approx(op(x_dense, y_dense), op(x_dense, y_dense))
 
     _assert_instance(res, asserted_type)
 
@@ -241,7 +244,7 @@ def generate(code):
 
         # If it is a scalar or vector, just pointwise square it.
         if len(shape) in {0, 1}:
-            return mat ** 2
+            return mat ** 2 + 1
         else:
             return B.matmul(mat, mat, tr_b=True) + B.eye(shape[0])
 
@@ -585,4 +588,4 @@ def kron_pd(request):
 )
 def kron_mixed(request):
     code1, code2 = request.param
-    return Kronecker(generate(code1), generate(code2))
+    return Kronecker(generate(code1), generate(code2))
\ No newline at end of file
